@@ -29,9 +29,14 @@ def getFileSize(file):
 
 def getAllFiles(path):
     result = []  # 所有的文件
+    pathLen = len(path)
     for maindir, subdir, file_name_list in os.walk(path):
         for filename in file_name_list:
             apath = os.path.join(maindir, filename)  # 合并成一个完整路径
+            apath = apath[pathLen:]
+            apath = apath.replace('\\', "/")
+            if apath.startswith("/"):
+                apath = apath[1:]
             result.append(apath)
         # for filename in subdir:
         #
@@ -103,12 +108,14 @@ def mergeFile(fileName,type,path):
         return False
 
 def getTotalSize(path, finishFiles):
+    if path.endswith("/")==False:
+        path = path + "/"
     targetFiles = getAllFiles(path)
     totalSize = 0
     for item in targetFiles:
         if item in finishFiles:
             continue
-        with open(item, 'a') as f:
+        with open(path+item, 'a') as f:
             fileSize = getFileSize(f)
             totalChunks = int(fileSize / chunkSize)
             lastSize = fileSize % chunkSize
@@ -119,8 +126,8 @@ def getTotalSize(path, finishFiles):
             totalSize = totalSize + totalChunks
     return totalSize
 
-def fileChunckUpLoad(apiUrl,fileName, chunkNumber, totalChunks, fileLength):
-    file = open(fileName, "rb")
+def fileChunckUpLoad(path,apiUrl,fileName, chunkNumber, totalChunks, fileLength):
+    file = open(path+fileName, "rb")
     file.seek(chunkSize*(chunkNumber-1))
     fileData = file.read(chunkSize)
 
@@ -146,6 +153,8 @@ def fileChunckUpLoad(apiUrl,fileName, chunkNumber, totalChunks, fileLength):
     return False
 
 def uploadPathFiles(id,type,uuid, path):
+    if path.endswith("/")==False:
+        path = path + "/"
     targetFiles = getAllFiles(path)
     finishFiles = {}
     finishChunk = {}
@@ -165,14 +174,14 @@ def uploadPathFiles(id,type,uuid, path):
         for item in targetFiles:
             if item in finishFiles.keys():
                 continue
-            with open(item, 'a') as f:
+            with open(path+item, 'a') as f:
                 fileSize = getFileSize(f)
                 totalChunks = int(fileSize / chunkSize)
                 lastSize = fileSize % chunkSize
                 if lastSize != 0:
                    totalChunks = totalChunks + 1
                 if totalChunks == 1 or totalChunks == 0 :
-                    result = fileChunckUpLoad(apiUrl, item, 1, 1, fileSize)
+                    result = fileChunckUpLoad(path, apiUrl, item, 1, 1, fileSize)
                     if result == True:
                         finishFiles[item] = True
                         saveFileProgress(id,item)
@@ -187,7 +196,7 @@ def uploadPathFiles(id,type,uuid, path):
                        if key in finishChunk.keys():
                            finishSize = finishSize + 1
                            continue
-                       result = fileChunckUpLoad(apiUrl,item,i+1,totalChunks,fileSize)
+                       result = fileChunckUpLoad(path,apiUrl,item,i+1,totalChunks,fileSize)
                        if result == True:
                             finishChunk[key] = True
                             saveChunkProgress(id, key)
